# stdlib
import os

# 3p
import argparse

# datadog
from datadog import initialize
from datadog.dogshell.comment import CommentClient
from datadog.dogshell.common import DogshellConfig
from datadog.dogshell.dashboard_list import DashboardListClient
from datadog.dogshell.downtime import DowntimeClient
from datadog.dogshell.event import EventClient
from datadog.dogshell.host import HostClient
from datadog.dogshell.metric import MetricClient
from datadog.dogshell.monitor import MonitorClient
from datadog.dogshell.screenboard import ScreenboardClient
from datadog.dogshell.search import SearchClient
from datadog.dogshell.service_check import ServiceCheckClient
from datadog.dogshell.tag import TagClient
from datadog.dogshell.timeboard import TimeboardClient
from datadog.dogshell.dashboard import DashboardClient
from datadog.util.config import get_version


def main():
    parser = argparse.ArgumentParser(description="Interact with the Datadog API",
                                     formatter_class=argparse.ArgumentDefaultsHelpFormatter)
    parser.add_argument('--config', help="location of your dogrc file (default ~/.dogrc)",
                        default=os.path.expanduser('~/.dogrc'))
    parser.add_argument('--api-key', help="your API key, from "
                        "https://app.datadoghq.com/account/settings#api",
                        dest='api_key', default=os.environ.get('DATADOG_API_KEY'))
    parser.add_argument('--application-key', help="your Application key, from "
                        "https://app.datadoghq.com/account/settings#api",
                        dest='app_key', default=os.environ.get('DATADOG_APP_KEY'))
    parser.add_argument('--pretty', help="pretty-print output (suitable for human consumption, "
                        "less useful for scripting)", dest='format',
                        action='store_const', const='pretty')
    parser.add_argument('--raw', help="raw JSON as returned by the HTTP service",
                        dest='format', action='store_const', const='raw')
    parser.add_argument('--timeout', help="time to wait in seconds before timing"
                        " out an API call (default 10)", default=10, type=int)
    parser.add_argument('-v', '--version', help='Dog API version', action='version',
                        version='%(prog)s {0}'.format(get_version()))

    config = DogshellConfig()

    # Set up subparsers for each service
    subparsers = parser.add_subparsers(title='Modes', dest='mode')
    subparsers.required = True

    CommentClient.setup_parser(subparsers)
    SearchClient.setup_parser(subparsers)
    MetricClient.setup_parser(subparsers)
    TagClient.setup_parser(subparsers)
    EventClient.setup_parser(subparsers)
    MonitorClient.setup_parser(subparsers)
    TimeboardClient.setup_parser(subparsers)
    DashboardClient.setup_parser(subparsers)
    ScreenboardClient.setup_parser(subparsers)
    DashboardListClient.setup_parser(subparsers)
    HostClient.setup_parser(subparsers)
    DowntimeClient.setup_parser(subparsers)
    ServiceCheckClient.setup_parser(subparsers)

    args = parser.parse_args()
    config.load(args.config, args.api_key, args.app_key)

    # Initialize datadog.api package
    initialize(**config)

    args.func(args)


if __name__ == '__main__':
    main()



from datadog.api.resources import (
    AddableAPISubResource,
    CreateableAPIResource,
    DeletableAPIResource,
    DeletableAPISubResource,
    GetableAPIResource,
    ListableAPIResource,
    ListableAPISubResource,
    UpdatableAPIResource,
    UpdatableAPISubResource
)


class DashboardList(AddableAPISubResource, CreateableAPIResource, DeletableAPIResource,
                    DeletableAPISubResource, GetableAPIResource, ListableAPIResource,
                    ListableAPISubResource, UpdatableAPIResource, UpdatableAPISubResource):
    """
    A wrapper around Dashboard List HTTP API.
    """
    _resource_name = 'dashboard/lists/manual'
    _sub_resource_name = 'dashboards'



"""
A small class to run a task periodically in a thread.
"""


from threading import Thread, Event


class PeriodicTimer(Thread):
    def __init__(self, interval, function, *args, **kwargs):
        Thread.__init__(self)
        self.daemon = True
        assert interval > 0
        self.interval = interval
        assert function
        self.function = function
        self.args = args
        self.kwargs = kwargs
        self.finished = Event()

    def _is_alive(self):
        # HACK: The Python interpreter can start cleaning up objects in the
        # main thread before killing daemon threads, so these references can be
        # null result in errors like that in case #18, tagged
        # "most likely raised during interpreter shutdown". This is hack to
        # try gracefully fail in these circumstances.
        #
        # http://stackoverflow.com/questions/1745232
        return (
            bool(self.finished) and
            bool(self.interval) and
            bool(self.function)
        )

    def end(self):
        if self._is_alive():
            self.finished.set()

    def run(self):
        while True:
            if not self._is_alive() or self.finished.isSet():
                break
            self.finished.wait(self.interval)
            self.function(*self.args, **self.kwargs)



from datadog.api.resources import CreateableAPIResource, UpdatableAPIResource, \
    DeletableAPIResource


class Comment(CreateableAPIResource, UpdatableAPIResource, DeletableAPIResource):
    """
    A wrapper around Comment HTTP API.
    """
    _resource_name = 'comments'



from datadog.api.resources import GetableAPIResource, CreateableAPIResource, \
    UpdatableAPIResource, ListableAPIResource, DeletableAPIResource


class Timeboard(GetableAPIResource, CreateableAPIResource,
                UpdatableAPIResource, ListableAPIResource,
                DeletableAPIResource):
    """
    A wrapper around Timeboard HTTP API.
    """
    _resource_name = 'dash'



"""
Reporter classes.
"""


from datadog import api


class Reporter(object):

    def flush(self, metrics):
        raise NotImplementedError()


class HttpReporter(Reporter):

    def flush_distributions(self, distributions):
        api.Distribution.send(distributions)

    def flush_metrics(self, metrics):
        api.Metric.send(metrics)

    def flush_events(self, events):
        for event in events:
            api.Event.create(**event)


class GraphiteReporter(Reporter):

    def flush(self, metrics):
        pass



# stdlib
import json

# 3p
from datadog.util.format import pretty_json

# datadog
from datadog import api
from datadog.dogshell.common import report_errors, report_warnings


class MonitorClient(object):
    @classmethod
    def setup_parser(cls, subparsers):
        parser = subparsers.add_parser('monitor', help="Create, edit, and delete monitors")
        parser.add_argument('--string_ids', action='store_true', dest='string_ids',
                            help="Represent monitor IDs as strings instead of ints in JSON")

        verb_parsers = parser.add_subparsers(title='Verbs', dest='verb')
        verb_parsers.required = True

        post_parser = verb_parsers.add_parser('post', help="Create a monitor")
        post_parser.add_argument('type', help="type of the monitor, e.g."
                                 "'metric alert' 'service check'")
        post_parser.add_argument('query', help="query to notify on with syntax varying "
                                 "depending on what type of monitor you are creating")
        post_parser.add_argument('--name', help="name of the alert", default=None)
        post_parser.add_argument('--message', help="message to include with notifications"
                                 " for this monitor", default=None)
        post_parser.add_argument('--options', help="json options for the monitor", default=None)
        post_parser.set_defaults(func=cls._post)

        update_parser = verb_parsers.add_parser('update', help="Update existing monitor")
        update_parser.add_argument('monitor_id', help="monitor to replace with the new definition")
        update_parser.add_argument('type', help="type of the monitor, e.g. "
                                   "'metric alert' 'service check'")
        update_parser.add_argument('query', help="query to notify on with syntax varying"
                                   " depending on what type of monitor you are creating")
        update_parser.add_argument('--name', help="name of the alert", default=None)
        update_parser.add_argument('--message', help="message to include with "
                                   "notifications for this monitor", default=None)
        update_parser.add_argument('--options', help="json options for the monitor", default=None)
        update_parser.set_defaults(func=cls._update)

        show_parser = verb_parsers.add_parser('show', help="Show a monitor definition")
        show_parser.add_argument('monitor_id', help="monitor to show")
        show_parser.set_defaults(func=cls._show)

        show_all_parser = verb_parsers.add_parser('show_all', help="Show a list of all monitors")
        show_all_parser.add_argument(
            '--group_states', help="comma separated list of group states to filter by"
            "(choose one or more from 'all', 'alert', 'warn', or 'no data')"
        )
        show_all_parser.add_argument('--name', help="string to filter monitors by name")
        show_all_parser.add_argument(
            '--tags', help="comma separated list indicating what tags, if any, "
            "should be used to filter the list of monitors by scope (e.g. 'host:host0')"
        )
        show_all_parser.add_argument(
            '--monitor_tags', help="comma separated list indicating what service "
            "and/or custom tags, if any, should be used to filter the list of monitors"
        )

        show_all_parser.set_defaults(func=cls._show_all)

        delete_parser = verb_parsers.add_parser('delete', help="Delete a monitor")
        delete_parser.add_argument('monitor_id', help="monitor to delete")
        delete_parser.set_defaults(func=cls._delete)

        mute_all_parser = verb_parsers.add_parser('mute_all', help="Globally mute "
                                                  "monitors (downtime over *)")
        mute_all_parser.set_defaults(func=cls._mute_all)

        unmute_all_parser = verb_parsers.add_parser('unmute_all', help="Globally unmute "
                                                    "monitors (cancel downtime over *)")
        unmute_all_parser.set_defaults(func=cls._unmute_all)

        mute_parser = verb_parsers.add_parser('mute', help="Mute a monitor")
        mute_parser.add_argument('monitor_id', help="monitor to mute")
        mute_parser.add_argument('--scope', help="scope to apply the mute to,"
                                 " e.g. role:db (optional)", default=[])
        mute_parser.add_argument('--end', help="POSIX timestamp for when"
                                 " the mute should end (optional)", default=None)
        mute_parser.set_defaults(func=cls._mute)

        unmute_parser = verb_parsers.add_parser('unmute', help="Unmute a monitor")
        unmute_parser.add_argument('monitor_id', help="monitor to unmute")
        unmute_parser.add_argument('--scope', help="scope to unmute (must be muted), "
                                   "e.g. role:db", default=[])
        unmute_parser.add_argument('--all_scopes', help="clear muting across all scopes",
                                   action='store_true')
        unmute_parser.set_defaults(func=cls._unmute)

    @classmethod
    def _post(cls, args):
        api._timeout = args.timeout
        format = args.format
        options = None
        if args.options is not None:
            try:
                options = json.loads(args.options)
            except:
                raise Exception('bad json parameter')
        res = api.Monitor.create(type=args.type, query=args.query, name=args.name,
                                 message=args.message, options=options)
        report_warnings(res)
        report_errors(res)
        if format == 'pretty':
            print(pretty_json(res))
        else:
            print(json.dumps(res))

    @classmethod
    def _update(cls, args):
        api._timeout = args.timeout
        format = args.format
        options = None
        if args.options is not None:
            try:
                options = json.loads(args.options)
            except:
                raise Exception('bad json parameter')
        res = api.Monitor.update(args.monitor_id, type=args.type, query=args.query,
                                 name=args.name, message=args.message, options=options)
        report_warnings(res)
        report_errors(res)
        if format == 'pretty':
            print(pretty_json(res))
        else:
            print(json.dumps(res))

    @classmethod
    def _show(cls, args):
        api._timeout = args.timeout
        format = args.format
        res = api.Monitor.get(args.monitor_id)
        report_warnings(res)
        report_errors(res)

        if args.string_ids:
            res["id"] = str(res["id"])

        if format == 'pretty':
            print(pretty_json(res))
        else:
            print(json.dumps(res))

    @classmethod
    def _show_all(cls, args):
        api._timeout = args.timeout
        format = args.format

        res = api.Monitor.get_all(
            group_states=args.group_states, name=args.name,
            tags=args.tags, monitor_tags=args.monitor_tags
        )
        report_warnings(res)
        report_errors(res)

        if args.string_ids:
            for d in res:
                d["id"] = str(d["id"])

        if format == 'pretty':
            print(pretty_json(res))
        elif format == 'raw':
            print(json.dumps(res))
        else:
            for d in res:
                print("\t".join([(str(d["id"])),
                                 (cls._escape(d["message"])),
                                 (cls._escape(d["name"])),
                                 (str(d["options"])),
                                 (str(d["org_id"])),
                                 (d["query"]),
                                 (d["type"])]))

    @classmethod
    def _delete(cls, args):
        api._timeout = args.timeout
        # TODO CHECK
        res = api.Monitor.delete(args.monitor_id)
        if res is not None:
            report_warnings(res)
            report_errors(res)

    @classmethod
    def _escape(cls, s):
        return s.replace("\r", "\\r").replace("\n", "\\n").replace("\t", "\\t")

    @classmethod
    def _mute_all(cls, args):
        api._timeout = args.timeout
        format = args.format
        res = api.Monitor.mute_all()
        report_warnings(res)
        report_errors(res)
        if format == 'pretty':
            print(pretty_json(res))
        else:
            print(json.dumps(res))

    @classmethod
    def _unmute_all(cls, args):
        api._timeout = args.timeout
        res = api.Monitor.unmute_all()
        if res is not None:
            report_warnings(res)
            report_errors(res)

    @classmethod
    def _mute(cls, args):
        api._timeout = args.timeout
        format = args.format
        res = api.Monitor.mute(args.monitor_id, scope=args.scope, end=args.end)
        report_warnings(res)
        report_errors(res)
        if format == 'pretty':
            print(pretty_json(res))
        else:
            print(json.dumps(res))

    @classmethod
    def _unmute(cls, args):
        api._timeout = args.timeout
        res = api.Monitor.unmute(args.monitor_id, scope=args.scope, all_scopes=args.all_scopes)
        report_warnings(res)
        report_errors(res)
        if format == 'pretty':
            print(pretty_json(res))
        else:
            print(json.dumps(res))



from datadog.api.resources import GetableAPIResource, CreateableAPIResource,\
    UpdatableAPIResource, ListableAPIResource, DeletableAPIResource


class Downtime(GetableAPIResource, CreateableAPIResource, UpdatableAPIResource,
               ListableAPIResource, DeletableAPIResource):
    """
    A wrapper around Monitor Downtiming HTTP API.
    """
    _resource_name = 'downtime'



# stdlib
import json

# 3p
from datadog.util.format import pretty_json

# datadog
from datadog import api
from datadog.dogshell.common import report_errors, report_warnings


class DowntimeClient(object):
    @classmethod
    def setup_parser(cls, subparsers):
        parser = subparsers.add_parser('downtime', help="Create, edit, and delete downtimes")
        parser.add_argument('--string_ids', action='store_true', dest='string_ids',
                            help="Represent downtime IDs as strings instead of ints in JSON")

        verb_parsers = parser.add_subparsers(title='Verbs', dest='verb')
        verb_parsers.required = True

        post_parser = verb_parsers.add_parser('post', help="Create a downtime")
        post_parser.add_argument('scope', help="scope to apply downtime to")
        post_parser.add_argument('start', help="POSIX timestamp to start the downtime",
                                 default=None)
        post_parser.add_argument('--end', help="POSIX timestamp to end the downtime", default=None)
        post_parser.add_argument('--message', help="message to include with notifications"
                                 " for this downtime", default=None)
        post_parser.set_defaults(func=cls._schedule_downtime)

        update_parser = verb_parsers.add_parser('update', help="Update existing downtime")
        update_parser.add_argument('downtime_id', help="downtime to replace"
                                   " with the new definition")
        update_parser.add_argument('--scope', help="scope to apply downtime to")
        update_parser.add_argument('--start', help="POSIX timestamp to start"
                                   " the downtime", default=None)
        update_parser.add_argument('--end', help="POSIX timestamp to"
                                   " end the downtime", default=None)
        update_parser.add_argument('--message', help="message to include with notifications"
                                   " for this downtime", default=None)
        update_parser.set_defaults(func=cls._update_downtime)

        show_parser = verb_parsers.add_parser('show', help="Show a downtime definition")
        show_parser.add_argument('downtime_id', help="downtime to show")
        show_parser.set_defaults(func=cls._show_downtime)

        show_all_parser = verb_parsers.add_parser('show_all', help="Show a list of all downtimes")
        show_all_parser.add_argument('--current_only', help="only return downtimes that"
                                     " are active when the request is made", default=None)
        show_all_parser.set_defaults(func=cls._show_all_downtime)

        delete_parser = verb_parsers.add_parser('delete', help="Delete a downtime")
        delete_parser.add_argument('downtime_id', help="downtime to delete")
        delete_parser.set_defaults(func=cls._cancel_downtime)

    @classmethod
    def _schedule_downtime(cls, args):
        api._timeout = args.timeout
        format = args.format
        res = api.Downtime.create(scope=args.scope, start=args.start,
                                  end=args.end, message=args.message)
        report_warnings(res)
        report_errors(res)
        if format == 'pretty':
            print(pretty_json(res))
        else:
            print(json.dumps(res))

    @classmethod
    def _update_downtime(cls, args):
        api._timeout = args.timeout
        format = args.format
        res = api.Downtime.update(args.downtime_id, scope=args.scope, start=args.start,
                                  end=args.end, message=args.message)
        report_warnings(res)
        report_errors(res)
        if format == 'pretty':
            print(pretty_json(res))
        else:
            print(json.dumps(res))

    @classmethod
    def _cancel_downtime(cls, args):
        api._timeout = args.timeout
        res = api.Downtime.delete(args.downtime_id)
        if res is not None:
            report_warnings(res)
            report_errors(res)

    @classmethod
    def _show_downtime(cls, args):
        api._timeout = args.timeout
        format = args.format
        res = api.Downtime.get(args.downtime_id)
        report_warnings(res)
        report_errors(res)
        if format == 'pretty':
            print(pretty_json(res))
        else:
            print(json.dumps(res))

    @classmethod
    def _show_all_downtime(cls, args):
        api._timeout = args.timeout
        format = args.format
        res = api.Downtime.get_all(current_only=args.current_only)
        report_warnings(res)
        report_errors(res)
        if format == 'pretty':
            print(pretty_json(res))
        else:
            print(json.dumps(res))



# flake8: noqa

# API settings
_api_key = None
_application_key = None
_api_version = 'v1'
_api_host = None
_host_name = None
_cacert = True

# HTTP(S) settings
_proxies = None
_timeout = 60
_max_timeouts = 3
_max_retries = 3
_backoff_period = 300
_mute = True

# Resources
from datadog.api.comments import Comment
from datadog.api.dashboard_lists import DashboardList
from datadog.api.distributions import Distribution
from datadog.api.downtimes import Downtime
from datadog.api.timeboards import Timeboard
from datadog.api.dashboards import Dashboard
from datadog.api.events import Event
from datadog.api.infrastructure import Infrastructure
from datadog.api.metadata import Metadata
from datadog.api.metrics import Metric
from datadog.api.monitors import Monitor
from datadog.api.screenboards import Screenboard
from datadog.api.graphs import Graph, Embed
from datadog.api.hosts import Host, Hosts
from datadog.api.service_checks import ServiceCheck
from datadog.api.tags import Tag
from datadog.api.users import User



# stdlib
import json
import sys

# datadog
from datadog import api
from datadog.dogshell.common import report_errors, report_warnings


class CommentClient(object):

    @classmethod
    def setup_parser(cls, subparsers):
        parser = subparsers.add_parser('comment', help="Post, update, and delete comments.")

        verb_parsers = parser.add_subparsers(title='Verbs', dest='verb')
        verb_parsers.required = True

        post_parser = verb_parsers.add_parser('post', help="Post comments.")
        post_parser.add_argument('--handle', help="handle to post as. if unset, posts as the owner"
                                 " of the application key used to authenticate")
        post_parser.add_argument('comment', help="comment message to post. if unset,"
                                 " reads from stdin.", nargs='?')
        post_parser.set_defaults(func=cls._post)

        update_parser = verb_parsers.add_parser('update', help="Update existing comments.")
        update_parser.add_argument('comment_id', help="comment to update (by id)")
        update_parser.add_argument('--handle', help="handle to post as. if unset, posts"
                                   " as the owner of the application key used to authenticate")
        update_parser.add_argument('comment', help="comment message to post."
                                   " if unset, reads from stdin.", nargs="?")
        update_parser.set_defaults(func=cls._update)

        reply_parser = verb_parsers.add_parser('reply', help="Reply to existing comments.")
        reply_parser.add_argument('comment_id', help="comment to reply to (by id)")
        reply_parser.add_argument('--handle', help="handle to post as. if unset, "
                                  "posts as the owner of the application key used to authenticate")
        reply_parser.add_argument('comment', help="comment message to post."
                                  " if unset, reads from stdin.", nargs="?")
        reply_parser.set_defaults(func=cls._reply)

        show_parser = verb_parsers.add_parser('show', help="Show comment details.")
        show_parser.add_argument('comment_id', help="comment to show")
        show_parser.set_defaults(func=cls._show)

        delete_parser = verb_parsers.add_parser('delete', help="Delete comments.")
        delete_parser.add_argument('comment_id', help="comment to delete (by id)")
        delete_parser.set_defaults(func=cls._delete)

    @classmethod
    def _post(cls, args):
        api._timeout = args.timeout
        handle = args.handle
        comment = args.comment
        format = args.format
        if comment is None:
            comment = sys.stdin.read()
        res = api.Comment.create(handle=handle, message=comment)
        report_warnings(res)
        report_errors(res)
        if format == 'pretty':
            message = res['comment']['message']
            lines = message.split('\n')
            message = '\n'.join(['    ' + line for line in lines])
            print('id\t\t' + str(res['comment']['id']))
            print('url\t\t' + res['comment']['url'])
            print('resource\t' + res['comment']['resource'])
            print('handle\t\t' + res['comment']['handle'])
            print('message\n' + message)
        elif format == 'raw':
            print(json.dumps(res))
        else:
            print('id\t\t' + str(res['comment']['id']))
            print('url\t\t' + res['comment']['url'])
            print('resource\t' + res['comment']['resource'])
            print('handle\t\t' + res['comment']['handle'])
            print('message\t\t' + res['comment']['message'].__repr__())

    @classmethod
    def _update(cls, args):
        handle = args.handle
        comment = args.comment
        id = args.comment_id
        format = args.format
        if comment is None:
            comment = sys.stdin.read()
        res = api.Comment.update(id, handle=handle, message=comment)
        report_warnings(res)
        report_errors(res)
        if format == 'pretty':
            message = res['comment']['message']
            lines = message.split('\n')
            message = '\n'.join(['    ' + line for line in lines])
            print('id\t\t' + str(res['comment']['id']))
            print('url\t\t' + res['comment']['url'])
            print('resource\t' + res['comment']['resource'])
            print('handle\t\t' + res['comment']['handle'])
            print('message\n' + message)
        elif format == 'raw':
            print(json.dumps(res))
        else:
            print('id\t\t' + str(res['comment']['id']))
            print('url\t\t' + res['comment']['url'])
            print('resource\t' + res['comment']['resource'])
            print('handle\t\t' + res['comment']['handle'])
            print('message\t\t' + res['comment']['message'].__repr__())

    @classmethod
    def _reply(cls, args):
        api._timeout = args.timeout
        handle = args.handle
        comment = args.comment
        id = args.comment_id
        format = args.format
        if comment is None:
            comment = sys.stdin.read()
        res = api.Comment.create(handle=handle, message=comment, related_event_id=id)
        report_warnings(res)
        report_errors(res)
        if format == 'pretty':
            message = res['comment']['message']
            lines = message.split('\n')
            message = '\n'.join(['    ' + line for line in lines])
            print('id\t\t' + str(res['comment']['id']))
            print('url\t\t' + res['comment']['url'])
            print('resource\t' + res['comment']['resource'])
            print('handle\t\t' + res['comment']['handle'])
            print('message\n' + message)
        elif format == 'raw':
            print(json.dumps(res))
        else:
            print('id\t\t' + str(res['comment']['id']))
            print('url\t\t' + res['comment']['url'])
            print('resource\t' + res['comment']['resource'])
            print('handle\t\t' + res['comment']['handle'])
            print('message\t\t' + res['comment']['message'].__repr__())

    @classmethod
    def _show(cls, args):
        api._timeout = args.timeout
        id = args.comment_id
        format = args.format
        res = api.Event.get(id)
        report_warnings(res)
        report_errors(res)
        if format == 'pretty':
            message = res['event']['text']
            lines = message.split('\n')
            message = '\n'.join(['    ' + line for line in lines])
            print('id\t\t' + str(res['event']['id']))
            print('url\t\t' + res['event']['url'])
            print('resource\t' + res['event']['resource'])
            print('message\n' + message)
        elif format == 'raw':
            print(json.dumps(res))
        else:
            print('id\t\t' + str(res['event']['id']))
            print('url\t\t' + res['event']['url'])
            print('resource\t' + res['event']['resource'])
            print('message\t\t' + res['event']['text'].__repr__())

    @classmethod
    def _delete(cls, args):
        api._timeout = args.timeout
        id = args.comment_id
        res = api.Comment.delete(id)
        if res is not None:
            report_warnings(res)
            report_errors(res)



from datadog.api.resources import GetableAPIResource, CreateableAPIResource, \
    UpdatableAPIResource, DeletableAPIResource


class Dashboard(GetableAPIResource, CreateableAPIResource,
                UpdatableAPIResource, DeletableAPIResource):
    """
    A wrapper around Dashboard HTTP API.
    """
    _resource_name = 'dashboard'
